@@ -1,11 +1,9 @@
 require 'simplecov'
-require 'coveralls'
 require 'support/projects'
 
 SimpleCov.formatter = SimpleCov::Formatter::MultiFormatter.new(
   [
     SimpleCov::Formatter::HTMLFormatter,
-    Coveralls::SimpleCov::Formatter
   ]
 )
 
